@@ -1,6 +1,7 @@
 import json
 import urllib.parse
 from socketdev.log import log
+from ..core.dedupe import Dedupe
 
 
 class Purl:
@@ -32,8 +33,9 @@ class Purl:
                         purl.append(item)
                     except json.JSONDecodeError:
                         continue
-            return purl
+            purl_deduped = Dedupe.dedupe(purl)
+            return purl_deduped
 
         log.error(f"Error posting {components} to the Purl API: {response.status_code}")
-        print(response.text)
+        log.error(response.text)
         return []
